DefaultApiError class

Default api error model that can be received from network response. can be updated based on the response.

Constructors

DefaultApiError({int? statusCode, String? name, String? message})
DefaultApiError.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited