DefaultEnglishExceptionMessage class
Default client error messages. To customize your messages you can override ExceptionMessage the same way as this class and customize the messages.
- Inheritance
-
- Object
- ExceptionMessage
- DefaultEnglishExceptionMessage
Constructors
- DefaultEnglishExceptionMessage()
-
const
Properties
- badRequest → String
-
no setteroverride
- conflict → String
-
no setteroverride
- defaultError → String
-
no setteroverride
- emptyResponse → String
-
no setteroverride
- formatException → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalServerError → String
-
no setteroverride
- noInternetConnection → String
-
no setteroverride
- notAcceptable → String
-
no setteroverride
- notFound → String
-
no setteroverride
- requestCancelled → String
-
no setteroverride
- requestTimeout → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendTimeout → String
-
no setteroverride
-
no setteroverride
- unableToProcess → String
-
no setteroverride
-
no setteroverride
- unexpectedError → String
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited