ExceptionMessage class abstract
Class that can be extended to implement your own custom errors message.
- Implementers
Constructors
- ExceptionMessage()
-
const
Properties
- badRequest → String
-
no setter
- conflict → String
-
no setter
- defaultError → String
-
no setter
- emptyResponse → String
-
no setter
- formatException → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalServerError → String
-
no setter
- noInternetConnection → String
-
no setter
- notAcceptable → String
-
no setter
- notFound → String
-
no setter
- requestCancelled → String
-
no setter
- requestTimeout → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendTimeout → String
-
no setter
-
no setter
- unableToProcess → String
-
no setter
-
no setter
- unexpectedError → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited